pub struct LaunchOptions {
pub monitor_root_job: Option<bool>,
/* private fields */
}Fields
monitor_root_job: Option<bool>Trait Implementations
Sourceimpl Clone for LaunchOptions
impl Clone for LaunchOptions
Sourcefn clone(&self) -> LaunchOptions
fn clone(&self) -> LaunchOptions
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LaunchOptions
impl Debug for LaunchOptions
Sourceimpl<D> Decode<LaunchOptions, D> for LaunchOptionswhere
D: ResourceDialect,
impl<D> Decode<LaunchOptions, D> for LaunchOptionswhere
D: ResourceDialect,
Sourcefn new_empty() -> LaunchOptions
fn new_empty() -> LaunchOptions
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl Default for LaunchOptions
impl Default for LaunchOptions
Sourcefn default() -> LaunchOptions
fn default() -> LaunchOptions
Returns the “default value” for a type. Read more
Sourceimpl<D> Encode<LaunchOptions, D> for &LaunchOptionswhere
D: ResourceDialect,
impl<D> Encode<LaunchOptions, D> for &LaunchOptionswhere
D: ResourceDialect,
Sourceimpl PartialEq for LaunchOptions
impl PartialEq for LaunchOptions
Sourcefn eq(&self, other: &LaunchOptions) -> bool
fn eq(&self, other: &LaunchOptions) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Persistable for LaunchOptions
impl StructuralPartialEq for LaunchOptions
Sourceimpl TypeMarker for LaunchOptions
impl TypeMarker for LaunchOptions
Sourcetype Owned = LaunchOptions
type Owned = LaunchOptions
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for LaunchOptions
impl ValueTypeMarker for LaunchOptions
Sourcetype Borrowed<'a> = &'a LaunchOptions
type Borrowed<'a> = &'a LaunchOptions
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<LaunchOptions as TypeMarker>::Owned,
) -> <LaunchOptions as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<LaunchOptions as TypeMarker>::Owned, ) -> <LaunchOptions as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for LaunchOptions
impl RefUnwindSafe for LaunchOptions
impl Send for LaunchOptions
impl Sync for LaunchOptions
impl Unpin for LaunchOptions
impl UnsafeUnpin for LaunchOptions
impl UnwindSafe for LaunchOptions