ThreadDetails

Struct ThreadDetails 

pub struct ThreadDetails {
    pub backtrace: Option<String>,
    /* private fields */
}
Details about a particular thread. The fields will be included as per the ThreadDetailsInterest supplied when creating the ProcessInfoIterator via |GetProcessInfo|.

Fields

backtrace: Option<String>

A stack trace from the current thread in symbolizer markup format.